@@ -1,14 +1,13 @@
 #
 # This file is part of Dancer2-Plugin-Feed
 #
-# This software is copyright (c) 2015 by Natal Ngétal.
+# This software is copyright (c) 2016 by Natal Ngétal.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
 package Dancer2::Plugin::Feed;
-$Dancer2::Plugin::Feed::VERSION = '1.152100';
-use Dancer2;
+$Dancer2::Plugin::Feed::VERSION = '1.160190';
 use Dancer2::Plugin;
 use XML::Feed;
 
@@ -30,10 +29,10 @@ register create_feed => sub {
 
     my $format = _validate_format(\%params);
 
-    if ($format =~ /^atom$/i) {
+    if (lc $format eq 'atom') {
         _create_atom_feed($dsl, \%params);
     }
-    elsif($format =~/^rss$/i) {
+    elsif(lc $format eq 'rss') {
         _create_rss_feed($dsl, \%params);
     }
     else {
@@ -63,7 +62,7 @@ sub _validate_format {
             or die "Feed format is missing\n";
     }
 
-    if ($format !~ /^(?:atom|rss)$/i) {
+    if (! exists $ct->{$format}) {
         die "Unknown format $format, use rss or atom\n";
     }
 
@@ -78,18 +77,18 @@ sub _create_feed {
     my $feed     = XML::Feed->new($format);
     my $settings = plugin_setting;
 
-    map {
+    foreach (@feed_properites) {
         my $val = $params->{$_} || $settings->{$_};
         $feed->$_($val) if ($val);
-    } @feed_properties;
+    }
 
     foreach my $entry (@$entries) {
         my $e = XML::Feed::Entry->new($format);
 
-        map {
+        foreach (@entries_properties) {
             my $val = $entry->{$_};
             $e->$_($val) if $val
-        } @entries_properties;
+        }
 
         $feed->add_entry($e);
     }
@@ -127,7 +126,7 @@ Dancer2::Plugin::Feed - Easy to generate feed rss or atom for Dancer2 applicatio
 
 =head1 VERSION
 
-version 1.152100
+version 1.160190
 
 =head1 SYNOPSIS
 
@@ -257,7 +256,7 @@ Natal Ngétal
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Natal Ngétal.
+This software is copyright (c) 2016 by Natal Ngétal.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
